==> linshare-core-1.6.0-src.tar.bz2: src/main/java/org/linagora/linshare/core/service/FunctionalityService.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */

package org.linagora.linshare.core.service;

import java.util.Set;

import org.linagora.linshare.core.domain.entities.AbstractDomain;
import org.linagora.linshare.core.domain.entities.Account;
import org.linagora.linshare.core.domain.entities.Functionality;
import org.linagora.linshare.core.exception.BusinessException;

public interface FunctionalityService {

	Set<Functionality> getAllFunctionalities(Account actor, AbstractDomain domain) throws BusinessException;

	Set<Functionality> getAllFunctionalities(Account actor, String domain) throws BusinessException;

	boolean activationPolicyIsMutable(Functionality f, String domain);

	boolean configurationPolicyIsMutable(Functionality f, String domain);

	/**
	 * Return a clone of the original functionality store into the database.
	 * @param actor
	 * @param domainId
	 * @param functionalityId
	 * @return
	 * @throws BusinessException
	 */
	Functionality getFunctionality(Account actor, String domainId, String functionalityId) throws BusinessException;

	void deleteFunctionality(Account actor, String domainId, String functionalityId) throws BusinessException;

	Functionality update(Account actor, String domain, Functionality functionality) throws BusinessException;

	@Deprecated
	void update(Account actor, AbstractDomain domain, Functionality functionality) throws BusinessException;
}

==> linshare-core-1.6.1-src.tar.bz2: src/main/java/org/linagora/linshare/core/service/FunctionalityService.java <==
/*
 * LinShare is an open source filesharing software, part of the LinPKI software
 * suite, developed by Linagora.
 * 
 * Copyright (C) 2014 LINAGORA
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version, provided you comply with the Additional Terms applicable for
 * LinShare software by Linagora pursuant to Section 7 of the GNU Affero General
 * Public License, subsections (b), (c), and (e), pursuant to which you must
 * notably (i) retain the display of the “LinShare™” trademark/logo at the top
 * of the interface window, the display of the “You are using the Open Source
 * and free version of LinShare™, powered by Linagora © 2009–2014. Contribute to
 * Linshare R&D by subscribing to an Enterprise offer!” infobox and in the
 * e-mails sent with the Program, (ii) retain all hypertext links between
 * LinShare and linshare.org, between linagora.com and Linagora, and (iii)
 * refrain from infringing Linagora intellectual property rights over its
 * trademarks and commercial brands. Other Additional Terms apply, see
 * <http://www.linagora.com/licenses/> for more details.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License and
 * its applicable Additional Terms for LinShare along with this program. If not,
 * see <http://www.gnu.org/licenses/> for the GNU Affero General Public License
 * version 3 and <http://www.linagora.com/licenses/> for the Additional Terms
 * applicable to LinShare software.
 */

package org.linagora.linshare.core.service;

import java.util.Set;

import org.linagora.linshare.core.domain.entities.AbstractDomain;
import org.linagora.linshare.core.domain.entities.Account;
import org.linagora.linshare.core.domain.entities.Functionality;
import org.linagora.linshare.core.exception.BusinessException;

public interface FunctionalityService {

	Set<Functionality> getAllFunctionalities(Account actor, AbstractDomain domain) throws BusinessException;

	Set<Functionality> getAllFunctionalities(Account actor, String domain) throws BusinessException;

	boolean activationPolicyIsMutable(Account actor, Functionality f, String domain) throws BusinessException;

	boolean configurationPolicyIsMutable(Account actor, Functionality f, String domain) throws BusinessException;

	boolean parametersAreMutable(Account actor, Functionality f, String domain) throws BusinessException;

	/**
	 * Return a clone of the original functionality store into the database.
	 * @param actor
	 * @param domainId
	 * @param functionalityId
	 * @return
	 * @throws BusinessException
	 */
	Functionality getFunctionality(Account actor, String domainId, String functionalityId) throws BusinessException;

	void deleteFunctionality(Account actor, String domainId, String functionalityId) throws BusinessException;

	Functionality update(Account actor, String domain, Functionality functionality) throws BusinessException;

	@Deprecated
	void update(Account actor, AbstractDomain domain, Functionality functionality) throws BusinessException;
}
